==> aliyun-java-sdk-ecs-4.20.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/AllocateDedicatedHostsResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.transform.v20140526;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.ecs.model.v20140526.AllocateDedicatedHostsResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class AllocateDedicatedHostsResponseUnmarshaller {

	public static AllocateDedicatedHostsResponse unmarshall(AllocateDedicatedHostsResponse allocateDedicatedHostsResponse, UnmarshallerContext _ctx) {
		
		allocateDedicatedHostsResponse.setRequestId(_ctx.stringValue("AllocateDedicatedHostsResponse.RequestId"));

		List<String> dedicatedHostIdSets = new ArrayList<String>();
		for (int i = 0; i < _ctx.lengthValue("AllocateDedicatedHostsResponse.DedicatedHostIdSets.Length"); i++) {
			dedicatedHostIdSets.add(_ctx.stringValue("AllocateDedicatedHostsResponse.DedicatedHostIdSets["+ i +"]"));
		}
		allocateDedicatedHostsResponse.setDedicatedHostIdSets(dedicatedHostIdSets);
	 
	 	return allocateDedicatedHostsResponse;
	}
}

==> aliyun-java-sdk-ecs-5.11.18-sources.jar: com/aliyuncs/ecs/transform/v20140526/AllocateDedicatedHostsResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.transform.v20140526;

import java.util.ArrayList;
import java.util.List;

import com.aliyuncs.ecs.model.v20140526.AllocateDedicatedHostsResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class AllocateDedicatedHostsResponseUnmarshaller {

	public static AllocateDedicatedHostsResponse unmarshall(AllocateDedicatedHostsResponse allocateDedicatedHostsResponse, UnmarshallerContext _ctx) {
		
		allocateDedicatedHostsResponse.setRequestId(_ctx.stringValue("AllocateDedicatedHostsResponse.RequestId"));
		allocateDedicatedHostsResponse.setOrderId(_ctx.stringValue("AllocateDedicatedHostsResponse.OrderId"));

		List<String> dedicatedHostIdSets = new ArrayList<String>();
		for (int i = 0; i < _ctx.lengthValue("AllocateDedicatedHostsResponse.DedicatedHostIdSets.Length"); i++) {
			dedicatedHostIdSets.add(_ctx.stringValue("AllocateDedicatedHostsResponse.DedicatedHostIdSets["+ i +"]"));
		}
		allocateDedicatedHostsResponse.setDedicatedHostIdSets(dedicatedHostIdSets);
	 
	 	return allocateDedicatedHostsResponse;
	}
}
